require 'mappers/spec_pdf_mapper'
require 'vin_service'

module UVCService
  include SpecPdfMapper
  include VinService
  include HttpRestClient

  VEHICLE_BY_UVC_URL =
    "#{BASE_URL}/UsedCarWS/UsedCarWS/UsedVehicle/UVC".freeze

  PDF_SPEC_BY_UVC_URL =
    "#{BASE_URL}/UsedCarWS/UsedCarWS/PDFSpecs".freeze

  def range_by_uvc(uvc_id, query_params = {})
    url = "#{VEHICLE_BY_UVC_URL}/#{uvc_id}"

    response = make_request(:get, url, query_params)
    return response unless response.last == 200
    [RangeValuesMapper.map_fields(response.first), response.last]
  end

  def spec_pdf_data(uvc, query_params = {})
    url = "#{PDF_SPEC_BY_UVC_URL}/#{uvc}"

    response = make_request(:get, url, query_params)
    return response unless response.last == 200
    [SpecPdfMapper.map_fields(response.first), response.last]
  end

  # This method is used by web-system to generate vehicle spec pdfs for appraisers
  def pdf_data_by_vin(vin, query_params = {})
    response = uvc_by_vin(vin, query_params)
    return response unless response.last == 200
    spec_pdf_data(response.first[:uvc], query_params)
  end
end
